summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/bin/server.rs5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/bin/server.rs b/src/bin/server.rs
index b30fa18..b2f72f8 100644
--- a/src/bin/server.rs
+++ b/src/bin/server.rs
@@ -125,8 +125,8 @@ fn main() -> ! {
}
};
- // Set GPIO5 as an input
- let mut button = Input::new(peripherals.GPIO5, Pull::Down);
+ // Set GPIO6 as an input
+ let mut button = Input::new(peripherals.GPIO6, Pull::Down);
info!("Waiting 500ms pre-init");
delay.delay_millis(500);
@@ -180,6 +180,7 @@ fn main() -> ! {
});
controller.set_configuration(&client_config);
net = Some(ap_comp);
+ break;
};
}
}